@@ -1,3 +1,4 @@
+from actionpack.actions.call import Call
 from actionpack.actions.make_request import MakeRequest
 from actionpack.actions.read_bytes import ReadBytes
 from actionpack.actions.read_input import ReadInput
@@ -7,6 +8,7 @@ from actionpack.actions.write_bytes import WriteBytes
 
 
 __all__ = [
+    'Call',
     'MakeRequest',
     'ReadBytes',
     'ReadInput',
